@@ -2,12 +2,8 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"Tps" <-
-function (x, Y, m = NULL, p = NULL, scale.type = "range", 
-    ...) 
-{
-
+"Tps" <- function(x, Y, m = NULL, p = NULL, scale.type = "range", 
+    ...) {
     x <- as.matrix(x)
     d <- ncol(x)
     if (is.null(p)) {
@@ -19,11 +15,8 @@ function (x, Y, m = NULL, p = NULL, scale.type = "range",
             stop(" m is too small  you must have 2*m -d >0")
         }
     }
-
     Tpscall <- match.call()
     Tpscall$cov.function <- "Thin plate spline radial basis functions (Rad.cov) "
-    Krig(x, Y, cov.function = Rad.cov, m = m, 
-        scale.type = scale.type, outputcall = Tpscall, p = p, GCV=TRUE,
-        ...)
+    Krig(x, Y, cov.function = Rad.cov, m = m, scale.type = scale.type, 
+        outputcall = Tpscall, p = p, GCV = TRUE, ...)
 }
-
