@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"cat.matrix" <-
-function (mat, digits = 8) 
-{
+"cat.matrix" <- function(mat, digits = 8) {
     nc <- ncol(mat)
     temp <- matrix(match(c(signif(mat, digits)), unique(c(signif(mat, 
         digits)))), ncol = nc)
