@@ -2,7 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-coef.Krig<- function( object,...){
-Krig.coef(object,...)$d}
-
+coef.Krig <- function(object, ...) {
+    Krig.coef(object, ...)$d
+}
