@@ -4,7 +4,7 @@
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 "drape.plot" <- function(x, y, z, z2 = NULL, col = tim.colors(64), 
     zlim = range(z, na.rm = TRUE), zlim2 = NULL, add.legend = TRUE, 
-    horizontal = TRUE, theta = 30, phi = 20, ...) {
+    horizontal = TRUE, theta = 30, phi = 20,breaks=NA, ...) {
     #
     # Thanks to JiHO for making corrections and useful extensions to this function
     #
@@ -38,15 +38,14 @@
     }
     # determine the colors for facets based on z2, the color scale and
     # the zlim2 z  limits
-    zcol <- drape.color(z2, col = col, zlim = zlim2)
+    drape.info <- drape.color(z2, col = col, zlim = zlim2, breaks=breaks)
     # draw filled wireframe and save perspective information
-    pm <- persp(x, y, z, theta = theta, phi = phi, col = zcol, 
-        zlim = zlim, ...)
-    # Well, any guesses what this does?
+    pm <- persp(x, y, z, theta = theta, phi = phi, 
+           col = drape.info$color.index, zlim = zlim, ...)
     # Note that zlim2 defines limits of color scale
     if (add.legend) {
         image.plot(zlim = zlim2, legend.only = TRUE, col = col, 
-            horizontal = horizontal)
+            horizontal = horizontal, breaks=drape.info$breaks)
     }
     # return pm if an assignment is made (see help file)
     invisible(pm)
