@@ -2,14 +2,11 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"fields.mkpoly" <-
-function (x, m = 2) 
-{
-
- if (m < 1) stop("'m' has to be larger than zero.")
- if (!is.matrix(x)) x <- as.matrix(x)	    
-
+"fields.mkpoly" <- function(x, m = 2) {
+    if (m < 1) 
+        stop("'m' has to be larger than zero.")
+    if (!is.matrix(x)) 
+        x <- as.matrix(x)
     d <- ncol(x)
     n <- nrow(x)
     nterms <- .Fortran("mkpoly", as.integer(m), as.integer(d), 
