@@ -2,7 +2,4 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"predict.se" <-
-function (object, ...) 
-UseMethod("predict.se")
+"predict.se" <- function(object, ...) UseMethod("predict.se")
