@@ -2,9 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"print.spatial.design" <-
-function (x,...) 
-{
+"print.spatial.design" <- function(x, ...) {
     print(x$design)
 }
