@@ -3,9 +3,10 @@
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 "splint" <- function(x, y, xgrid, wt = NULL, derivative = 0, 
-    lam = 0, df = NA) {
+    lam = 0, df = NA, lambda=NULL) {
     #
     # reform calling args if passed as a matrix or list
+
     if (is.matrix(x)) {
         if (ncol(x) > 1) {
             xgrid <- y
@@ -38,6 +39,10 @@
         }
         lam <- sreg.df.to.lambda(df, x, wt)
     }
+    # use lambda is it is passed
+    if (!is.null(lambda)) {
+        lam<- lambda
+    }
     igcv <- ifelse(lam == 0, 2, 0)
     # call to old FORTRAN
     .Fortran("css", h = as.double(ifelse(igcv == 2, 1, log(lam))), 
