@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"stats.bin" <-
-function (x, y, N = 10, breaks = NULL) 
-{
+"stats.bin" <- function(x, y, N = 10, breaks = NULL) {
     out <- list()
     if (is.null(breaks)) {
         breaks <- pretty(x, N)
