@@ -2,11 +2,8 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"summary.qsreg" <-
-function (object, ...) 
-{
-    x<- object #hack S3
+"summary.qsreg" <- function(object, ...) {
+    x <- object
     digits <- 4
     c1 <- "Number of Observations:"
     c2 <- (x$N)
@@ -15,7 +12,8 @@ function (object, ...)
     c1 <- c(c1, "Residual degrees of freedom:")
     c2 <- c(c2, format(round(x$N - x$trace[x$ind.cv.ps], 1)))
     c1 <- c(c1, "Log10(lambda)")
-    c2 <- c(c2, format(round(log10(x$cv.grid[x$ind.cv.ps,1]), 2)))
+    c2 <- c(c2, format(round(log10(x$cv.grid[x$ind.cv.ps, 1]), 
+        2)))
     sum <- cbind(c1, c2)
     dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
     cat("Call:\n")
