@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"unscale" <-
-function (x, x.center, x.scale) 
-{
+"unscale" <- function(x, x.center, x.scale) {
     x <- scale(x, center = FALSE, scale = 1/x.scale)
     x <- scale(x, center = -x.center, scale = FALSE)
     x
